@@ -74,6 +74,8 @@ class HistoryItem(BaseModel):
     responseTime: Optional[float] = None
     inputTokens: Optional[int] = None
     outputTokens: Optional[int] = None
+    cacheCreationInputTokens: Optional[int] = None
+    cacheReadInputTokens: Optional[int] = None
     moneySpent: Optional[float] = None
     userMark: Optional[HistoryMark] = None
     operatorMark: Optional[HistoryMark] = None
@@ -81,6 +83,8 @@ class HistoryItem(BaseModel):
     fileNames: List[str]
     assistantId: Optional[str] = None
     thoughts: Optional[List[Thought]] = Field(default_factory=list)
+    workflowExecutionRef: Optional[str] = None
+    executionId: Optional[str] = None
 
 
 class ContextItem(BaseModel):
@@ -96,6 +100,7 @@ class ToolItem(BaseModel):
     name: str
     label: Optional[str]
     settings_config: Optional[bool]
+    description: Optional[str] = None
     user_description: Optional[str]
 
 
@@ -105,7 +110,7 @@ class AssistantDataItem(BaseModel):
     assistant_id: str
     assistant_name: str
     assistant_icon: Optional[str]
-    assistant_type: str
+    assistant_type: Optional[str]
     context: List[Union[ContextItem, str]]
     tools: List[ToolItem]
     conversation_starters: List[str]
@@ -126,8 +131,8 @@ class AssistantDetailsData(BaseModel):
 
     assistant_id: str
     assistant_name: str
-    assistant_icon: str
-    assistant_type: str
+    assistant_icon: Optional[str]
+    assistant_type: Optional[str]
     context: List[Union[ContextItem, str]]
     tools: List[ToolItem]
     conversation_starters: List[str]
@@ -165,10 +170,35 @@ class ConversationDetails(BaseModel):
     assistant_details: Optional[AssistantDetailsData]
     user_abilities: Optional[List[str]]
     is_folder_migrated: bool
+    is_workflow_conversation: Optional[bool] = None
     category: Optional[str]
     mcp_server_single_usage: Optional[bool] = False
 
 
+class ConversationShareRequest(BaseModel):
+    """Model for creating share conversation request."""
+
+    chat_id: str
+
+
+class ConversationShareResponse(BaseModel):
+    """Model for conversation share response."""
+
+    share_id: str
+    token: str
+    created_at: str
+    access_count: int
+
+
+class SharedConversationResponse(BaseModel):
+    """Model for shared conversation details response."""
+
+    conversation: ConversationDetails
+    shared_by: str
+    created_at: str
+    access_count: int
+
+
 class BaseResponse(BaseModel):
     """Generic base response model with message field."""
 
